/*
 *  playlist-mp3.h
 *  mod_musicindex
 *
 *  $Id: playlist-mp3.h 1010 2012-08-07 13:38:34Z varenet $
 *
 *  Created by Regis BOUDIN on Thu Jan 22 2004.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *   
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */
 
#ifndef PLAYLIST_MP3_H
#define PLAYLIST_MP3_H

#include "mod_musicindex.h"

mu_ent *make_mp3_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
	const char *const filename);
#endif
